# Virtru TDF3 SDK

## License

The following files are covered under the MIT license:

* tdf3_constants.h
* tdf3_exception.h
* tdf3_logging_interface.h
* virtru_client.h
* virtru_encrypt_file_param.h
* virtru_policy.h
* virtru_sample.cpp
* CMakeLists.txt
* virtru_sample.py
* __init__.py
* setup.py

The following binaries / minified libraries are subject to use under the "Virtru Data Protection Subscription Agreement" 
found here: https://www.virtru.com/terms-of-service/ 

* virtru_tdf3_python.pyd
* virtru_tdf3_python.so
* libvirtru_tdf3_static.a
* libvirtru_tdf3_static_combined.a
* libvirtru_tdf3.dylib
* libvirtru_tdf3.so
* virtru_tdf3_static.lib
* virtru_tdf3_static_combined.lib
* virtru_tdf3.dll
* tdf3
* tdf3.exe

All 3rd party packages used in this software are covered by their respective
licenses, which are detailed in the LICENSE file.

## Obtaining a Virtru AppId

 A Virtru `AppId` token is required to use the TDF3 SDK. [This is how you obtain it](https://developer.virtru.com/docs/how-to-download-appid-token) 

## The Virtru TDF3 C++ Sample

For more information on how to use the TDF3 C++ libraries, see the [online documentation](https://docs.developer.virtru.com/cpp/latest).

### Windows

1. Unpack the zip file

2. Open a command prompt window, and go to the `sample` directory 

3. Generate the Visual Studio files using cmake (https://cmake.org) by issuing the command `cmake -G "Visual Studio 15 2017 Win64"`

4. Open the `virtru_tdf3_sample.sln` file with Visual Studio

5. Select `Release` in the configuation mode dropdown

6. Edit the `virtru_sample.cpp` file and fill in your owner email address and associated appId values.

7. Select `Build solution` under the `Build` menu to do the compile and link

8. Run the resulting `virtru_tdf3_sample.exe` executable 

### OSX

1. Unpack the tar.gz file

2. Open a terminal window, and go to the `sample` directory 

3. Generate the makefile using cmake (https://cmake.org) by issuing the command `cmake .`

4. Edit the `virtru_sample.cpp` file and fill in your owner email address and associated appId values.

5. Issue the command `make` to do the compile and link

6. Run the resulting `virtru_tdf3_sample` executable 

### Linux

1. Unpack the tar.gz file

2. Open a terminal window, and go to the `sample` directory 

3. Generate the makefile using cmake (https://cmake.org) by issuing the command `cmake -G "Eclipse CDT4 - Unix Makefiles"`

4. Edit the `virtru_sample.cpp` file and fill in your owner email address and associated appId values.

5. Issue the command `make` to do the compile and link

6. Run the resulting `virtru_tdf3_sample` executable 

## The Virtru TDF3 Python Sample

For more information on how to use the TDF3 Python module, see the [online documentation](https://docs.developer.virtru.com/python/latest).

### General
+ [Python](http://www.python.org "Python home page") This module is built with Python3 libraries so it will ONLY work
with python3.

The module works on Linux, Windows and OSX. 

## Installing the module

### OS X And Linux
+ Navigate to `cd lib` and run `sudo python3 setup.py install`. The Virtru SDK module will build and install the module to `site-packages`.

```
$ sudo python3 setup.py install
running install
running build
running build_py
creating build
creating build/lib
creating build/lib/virtru_tdf3_python
copying virtru_tdf3_python/__init__.py -> build/lib/virtru_tdf3_python
copying virtru_tdf3_python/virtru_tdf3_python.so -> build/lib/virtru_tdf3_python
running install_lib
copying build/lib/virtru_tdf3_python/__init__.py -> /usr/local/lib/python3.7/site-packages/virtru_tdf3_python
copying build/lib/virtru_tdf3_python/virtru_tdf3_python.so -> /usr/local/lib/python3.7/site-packages/virtru_tdf3_python
byte-compiling /usr/local/lib/python3.7/site-packages/virtru_tdf3_python/__init__.py to __init__.cpython-37.pyc
running install_egg_info
Writing /usr/local/lib/python3.7/site-packages/virtru_tdf3_python-1.0.11-py3.7.egg-info
```

### Windows

`Make sure the Python installed on your windows machine is 64-bit.`

+ Navigate to `cd lib` and run `python setup.py install` and will build and install the module to `site-packages`.

```
PS C:\Users\..\lib> python setup.py install
running install
running build
running build_py
creating build
creating build\lib
creating build\lib\virtru_tdf3_python
copying virtru_tdf3_python\__init__.py -> build\lib\virtru_tdf3_python
copying virtru_tdf3_python\virtru_tdf3_python.pyd -> build\lib\virtru_tdf3_python
running install_lib
copying build\lib\virtru_tdf3_python\virtru_tdf3_python.pyd -> C:\Users\sujan\AppData\Local\Programs\Python\Python37\Lib\site-packages\virtru_tdf3_python
copying build\lib\virtru_tdf3_python\__init__.py -> C:\Users\sujan\AppData\Local\Programs\Python\Python37\Lib\site-packages\virtru_tdf3_python
byte-compiling C:\Users\sujan\AppData\Local\Programs\Python\Python37\Lib\site-packages\virtru_tdf3_python\__init__.py to __init__.cpython-37.pyc
running install_egg_info
Writing C:\Users\sujan\AppData\Local\Programs\Python\Python37\Lib\site-packages\virtru_tdf3_python-1.0.10-py3.7.egg-info
```

## Running the sample

+ Navigate to the `sample` directory and update `virtru_sample.py` script with your `AppId`
 
+ Run `python3 virtru_sample.py` to see how the files in the sample directory get encrypted and how to apply controls.
